import { css } from "@linaria/core";
import { defineComponent, onMounted, ref } from "vue";
import { string } from "vue-types";
import { useEditor } from "../../..";

export const View = defineComponent({
  props: {
    compId: string().isRequired,
  },
  emits: ["dblclick"],
  setup(props, { slots, emit }) {
    const compRef = ref();
    const { store, actions, helper } = useEditor();

    onMounted(() => {
      const comp = helper.findComp(props.compId);
      if (comp) {
        Object.defineProperty(comp, "$el", {
          value: compRef.value,
          configurable: true,
        });
      }
    });

    return () => {
      const comp = helper.findComp(props.compId);
      if (!comp) return store.isEditMode ? <div>无效组件</div> : null;

      return (
        <div
          ref={compRef}
          class={[viewStyle, store.isEditMode && editCompStyle]}
          style={helper.createStyle(comp.layout)}
          onClick={(e) => {
            e.stopPropagation();
            if (store.isEditMode) {
              actions.pickComp(props.compId);
            }
          }}
          onDblclick={() => emit("dblclick")}
        >
          {slots.default?.()}
        </div>
      );
    };
  },
});

const viewStyle = css`
  position: relative;
  font-size: 0;
  cursor: pointer;

  > :first-child {
    width: 100%;
    height: 100%;
  }
`;

const editCompStyle = css`
  &:hover {
    outline: 2px dashed @inf-primary-color;
  }
`;
