import { css, cx } from "@linaria/core";
import { Image, View } from "@queenjs/ui";
import { Checkbox, Radio, RadioChangeEvent } from "ant-design-vue";
import { defineUI, queenApi } from "queenjs";
import { reactive } from "vue";
import { any, bool } from "vue-types";
import PreviewModal from "../../components/PreviewModal";

const options = [
  { label: "1倍", value: 1 },
  { label: "2倍", value: 2 },
];

export default defineUI({
  props: {
    active: bool(),
    record: any(),
  },
  emits: ["select", "change"],
  setup(props, { emit }) {
    const state = reactive({
      qos: 1,
    });

    const change = (e: RadioChangeEvent) => {
      state.qos = e.target.value;
      emit("change", state.qos);
    };

    const showModal = () => {
      queenApi.dialog(
        <PreviewModal
          data={{ url: props.record?.thumbnailUrl, fileType: "image" }}
        />,
        {
          title: "预览渲染模板",
          width: "1000px",
        }
      );
    };

    return () => {
      const { active, record } = props;

      return (
        <div class="cursor-pointer">
          <View
            ratio={1.4}
            onClick={() => emit("select")}
            class={cx(
              itemStyles,
              "relative overflow-hidden group",
              active && "active"
            )}
          >
            {active && (
              <Checkbox checked class="!-mt-0.2em absolute top-0 left-0 z-3" />
            )}
            <Image class="h-1/1 w-1/1" src={record?.thumbnailUrl} />
            <span
              class="absolute left-1/2 top-1/2 z-3 transform -translate-x-1/2 -translate-y-1/2 rounded-1/2 w-56px leading-56px text-center bg-primary transition-all opacity-0 group-hover:opacity-100 hover:(bg-opacity-50)"
              onClick={(e) => {
                e.stopPropagation();
                showModal();
              }}
            >
              预览
            </span>
          </View>
          <div>
            <div class="py-8px">
              尺寸：{record.width} * {record.height}
            </div>
            <div>
              渲染分辨率：
              <Radio.Group
                disabled={!props.active}
                value={state.qos}
                options={options}
                onChange={change}
              />
            </div>
          </div>
        </div>
      );
    };
  },
});

const itemStyles = css`
  border: 1px solid transparent;
  &.active {
    border-color: @inf-primary-color;
  }
`;
