import AssetsList from "@/components/AssetsList";
import { MaterialController } from "@/modules/resource/controllers/MaterialController";
import { css } from "@linaria/core";
import { defineUI } from "queenjs";
import { onMounted } from "vue";
import { any } from "vue-types";
import MaterialItem from "./MaterialItem";
import Toolbar from "./MaterialToolbar";


export default defineUI({
    props: {
        Controller: any<MaterialController>().isRequired,
    },
    slots: {
        Toolbar,
        AssetsList,
        MaterialItem,
    },

    setup(props, { slots }) {
        onMounted(() => {
             props.Controller.getCurrControl().loadPage(1);
        });

        return ()=>{
            const state = props.Controller.state;
            const control = props.Controller.getCurrControl()
            
            return (<div class={rootStyles}>
              {
                !state.isSelect &&  <h3 class="text-22px">我的素材</h3>
              }

            <slots.Toolbar Controller={props.Controller} />

            <slots.AssetsList
              columns={6}
              class="mt-30px"
              control={control}
              item={(record: any) => (
                <slots.MaterialItem
                  record={record}
                  use={ state.currTab == "task" ? "task" : (state.isSelect? "select": "show")}
                  onDelete={() => props.Controller.onItemClick("delete", record)}
                  onDownload={() =>props.Controller.onItemClick("download", record)}
                  onUse={()=>props.Controller.onItemClick("use", record)}
                  onPreview={() =>props.Controller.onItemClick("preview", record)}
                />
              )}
            />
          </div>);
        }
    },

})

const rootStyles = css`
  .btn_tab {
    padding: 3px 5px;
    &:hover,
    &.active {
      color: @inf-primary-color;
    }
  }
`;
